@@ -1,7 +1,7 @@
 #' Manipulation and combination of belief functions
 #' 
 #' @description Package dst allows you to make basic probability assignments on subsets of a set of possibilities (events) and combine these events with Dempster's rule of combination.
-#' @author Claude Boivin, Stat.ASSQ <webapp.cb@gmail.com>
+#' @author Claude Boivin <webapp.cb@gmail.com>
 #' @details The main operations that can be done are: \itemize{
 #' \item definition of a basic chance assignment (bca) distribution on a variable,
 #'  \item combination of two bca's defined on the same variable,
@@ -9,6 +9,6 @@
 #'  \item extension of a bca,
 #'  \item marginalization of a bca. 
 #'  }
-#' @docType package
-#' @name dst
+#' @keywords internal
+"_PACKAGE"
 NULL
\ No newline at end of file
